Struct PrimarySelectionOffer
pub struct PrimarySelectionOffer { /* private fields */ }wayland_platform only.Expand description
Wrapper around the ZwpPrimarySelectionOfferV1.
Implementations
impl PrimarySelectionOffer
impl PrimarySelectionOffer
pub fn with_mime_types<T, F>(&self, callback: F) -> T
pub fn with_mime_types<T, F>(&self, callback: F) -> T
Inspect the mime types available on the given offer.
pub fn receive(&self, mime_type: String) -> Result<ReadPipe, Error>
pub fn receive(&self, mime_type: String) -> Result<ReadPipe, Error>
Request to receive the data of a given mime type.
You can call this function several times.
Note that you should not read the contents right away in a blocking way, as you may deadlock your application doing so. At least make sure you flush your events to the server before doing so.
Fails if too many file descriptors were already open and a pipe could not be created.
pub fn receive_to_fd(&self, mime_type: String, writefd: OwnedFd)
pub fn receive_to_fd(&self, mime_type: String, writefd: OwnedFd)
Request to receive the data of a given mime type, writen to writefd.
The provided file destructor must be a valid FD for writing, and will be closed once the contents are written.